#ifndef GLWIDGET_H
#define GLWIDGET_H

#include <QtOpenGL/QGLWidget>
#include "Image.h"
#include "ImageReader.h"
#include "Simulator.cuh"

class GLWidget : public QGLWidget
{
	Q_OBJECT
public:
	GLWidget(QWidget *parent = 0);
	~GLWidget();

	QSize minimumSizeHint() const;
	QSize sizeHint() const;
	void setFilename(QString fn);
	QString getFilename();
	void loadScene();
	void continueSimulation();
	void stopSimulation();
	void setWindDirection(QString dir);

protected:
	void initializeGL();
	void paintGL();
	void resizeGL(int width, int height);

private:
	void initVertices(int w, int h);
	void initColors(int w, int h, unsigned int *types);
	void initIndices(int w, int h);
	void updateColors(unsigned int *types, int w, int h, float *densities);
	void writeDensities(int iter, int width, int height, float *densities);

	QColor qtPurple;
	ImageReader ir;
	Image *image;
	Simulator *sim;
	bool simulate;

	QString filename;
	int scene_width;
	int scene_height;
	unsigned int *sim_types;
	float *sim_velocities, *sim_densities;
	int iter;
	QString *wind_dir;
};

#endif