#ifndef SIMULATOR_H
#define SIMULATOR_H

#include "Image.h"
#include <cuda_runtime.h>

class Simulator {
private:
	int a_sim_width;						//Value of simulation width
	int a_sim_height;						//Value of simulation height
	//float a_inputvel;						//Value of wind input velocity
	unsigned int *a_ctype;					//Map of simulation cells types
	float *a_f0;							//Map of LBM 2D9 f
	float2 *a_u;							//Map of simulation velocities
	float *a_rho;							//Map of simulation densities
	float2 a_wind_direction;				//Value of simulation wind direction
	//Auxiliar values
	float2 a_lbmvecs[9];
	int a_lbmnext[9];
	int a_lbmref_addr[9];
	float a_addWind[9];
	//Device pointers
	unsigned int *d_celltype;
	float *d_rho, *d_f0, *d_f1, *d_addWind;
	float2 *d_u;

	/*__device__ float equilibrium(float rho, float2 uu, float weight, float vec);
	__global__ void InitLBM(unsigned int *celltype, float *f_0, float2 *uu, float *rho);
	__global__ void LBMstep(unsigned int *celltype, float *rho, float2 *u, float *f_0, float *f_1, float omega);*/
public:
	Simulator();
	Simulator(int width, int height);
	~Simulator();
	unsigned int* initialise(Image *img);
	int nextIteration(float *velocities, float *densities);
	float* getVelocities();
	float* getDensities();
	float* getForces();
	unsigned int* getTypes();
	void setWindDirection(float x, float y);
};

#endif