#include "qtui.h"
#include <QVBoxLayout>
#include <qmessagebox.h>
#include <qfiledialog.h>

QtUI::QtUI(QWidget *parent)
	: QWidget(parent)
{
	ui.setupUi(this);

	play = true;
	scene_load = false;

	QVBoxLayout *mainLayout = new QVBoxLayout(this);

	createButtonsGroupBox();
	mainLayout->addWidget(m_groupBoxButtons);
	
	m_glwidget = new GLWidget(parent);
	mainLayout->addWidget(m_glwidget, 0);

	createWindChanger();
	//createInfoPanel();
}

QtUI::~QtUI()
{

}

void QtUI::updateButtonIcon()
{
	m_buttonPlayPause->setIcon(QIcon("Images/PlayButton_nb.png"));
}

void QtUI::updateButtonIconFocus()
{
	m_buttonPlayPause->setIcon(QIcon("Images/PlayButtonFocus_nb.png"));
}

void QtUI::buttonPlayPauseClicked()
{
	if(play) {
		if(m_glwidget->getFilename() != QString(QLatin1String(""))) {
			//QMessageBox::information(this, tr("Console"), "Play animation");
			m_glwidget->continueSimulation();
			play = false;
			m_buttonPlayPause->setIcon(QIcon("Images/PauseButton_nb.png"));
		} else {
			QMessageBox::information(this, tr("Error Console"), "No scene load, open a scene first");
		}
	} else {
		//QMessageBox::information(this, tr("Console"), "Pause animation");
		m_glwidget->stopSimulation();
		play = true;
		m_buttonPlayPause->setIcon(QIcon("Images/PlayButton_nb.png"));
	}
	
}

/*void QtUI::buttonInfoClicked()
{
	if(!info_clicked) {
		info_clicked = true;
		if(scene_load) {
			m_glwidget->stopSimulation();
			//QMessageBox::information(this, tr("Console"), "Change Wind");
			m_infopanel->show();
		} else {
			QMessageBox::information(this, tr("Error"), "No scene load, open a scene first");
		}
	} else {
		info_clicked = false;
		m_infopanel->hide();
		if(scene_load && !play) {
			m_glwidget->continueSimulation();
		}
	}
	
}*/

void QtUI::buttonOpenSceneClicked()
{
	QString filename;

	if(!play) {
		m_glwidget->stopSimulation();
		play = true;
		m_buttonPlayPause->setIcon(QIcon("Images/PlayButton_nb.png"));
	}

	filename = QFileDialog::getOpenFileName(this, tr("Open Scene"), "C://", "All Files (*.*)");
	if(filename != QString("")) {
		scene_load = true;
		m_glwidget->setFilename(filename);
		m_glwidget->loadScene();
		//m_infopanel->setImageName(filename);
		//QMessageBox::information(this, tr("File Name"), filename);
	}

	//if(!play) m_glwidget->continueSimulation();
}

void QtUI::buttonChangeWindClicked()
{
	if(scene_load) {
		m_glwidget->stopSimulation();
		//QMessageBox::information(this, tr("Console"), "Change Wind");
		m_windchanger->show();
	} else {
		QMessageBox::information(this, tr("Error"), "No scene load, open a scene first");
	}
}

void QtUI::updateWindDirection(/*QString dir*/)
{
	QString *dir = 	m_windchanger->getWind();
	//QMessageBox::information(this, tr("Console"), *dir);
	m_glwidget->setWindDirection(*dir);
	if(!play) m_glwidget->continueSimulation();
}

void QtUI::createButtonsGroupBox()
{
	m_groupBoxButtons = new QGroupBox(tr("Buttons"));

	QHBoxLayout *layout = new QHBoxLayout;

	m_buttonPlayPause = new MyQPushButton(this);
	//m_buttonPlayPause->setCheckable(true);
	//m_buttonPlayPause->setStyleSheet("QPushButton {icon: 'Images/PlayButton_nb.png'} QPushButton:focus {icon: 'Images/PlayButtonFocus_nb.png'}");
	m_buttonPlayPause->setIcon(QIcon("Images/PlayButton_nb.png"));
	connect(m_buttonPlayPause, SIGNAL(getFocusIn()), this, SLOT(updateButtonIconFocus()));  //No funciona!!!
	connect(m_buttonPlayPause, SIGNAL(getFocusOut()), this, SLOT(updateButtonIcon()));		//No funciona!!!
	connect(m_buttonPlayPause, SIGNAL(clicked()), this, SLOT(buttonPlayPauseClicked()));

	//m_buttonInfo = new MyQPushButton(this);
	//m_buttonInfo->setText("i");
	//connect(m_buttonInfo, SIGNAL(clicked()), this, SLOT(buttonInfoClicked()));

	m_buttonOpenScene = new MyQPushButton(this);
	m_buttonOpenScene->setIcon(QIcon("Images/OpenSceneButton_nb.png"));
	connect(m_buttonOpenScene, SIGNAL(clicked()), this, SLOT(buttonOpenSceneClicked()));
	
	m_buttonChangeWindDir = new MyQPushButton(this);
	m_buttonChangeWindDir->setIcon(QIcon("Images/ChangeWindButton_nb.png"));
	connect(m_buttonChangeWindDir, SIGNAL(clicked()), this, SLOT(buttonChangeWindClicked()));

	layout->addWidget(m_buttonPlayPause, 0, Qt::AlignHCenter);
	//layout->addWidget(m_buttonInfo, 0, Qt::AlignHCenter);
	layout->addWidget(m_buttonOpenScene, 0, Qt::AlignHCenter);
	layout->addWidget(m_buttonChangeWindDir, 0, Qt::AlignHCenter);

	m_groupBoxButtons->setLayout(layout);
}

void QtUI::createWindChanger()
{
	m_windchanger = new WindChanger(this);
	m_windchanger->setFixedSize(QSize(200,200));
	
	QPalette *Pal = new QPalette();
	Pal->setColor(QPalette::Background, Qt::white);
	m_windchanger->setAutoFillBackground(true);
	m_windchanger->setPalette(*Pal);

	m_windchanger->setParent(this);
	m_windchanger->hide();

	m_windchanger->setWindDirection(QString("N"));
	
	QPoint localPoint(300, 200);
	QPoint windowPoint = this->mapTo(this->window(), localPoint);
	m_windchanger->move(windowPoint);

	connect(m_windchanger, SIGNAL(windChanged(/*QString*/)), this, SLOT(updateWindDirection(/*QString*/)));
}

/*void QtUI::createInfoPanel()
{
	info_clicked = false;

	m_infopanel = new InformationPanel(this);
	m_infopanel->setFixedSize(QSize(200,200));
	
	QPalette *Pal = new QPalette();
	Pal->setColor(QPalette::Background, Qt::white);
	m_infopanel->setAutoFillBackground(true);
	m_infopanel->setPalette(*Pal);

	m_infopanel->setParent(this);
	m_infopanel->hide();

	m_infopanel->setWindDir(QString("N"));
	
	QPoint localPoint(300, 200);
	QPoint windowPoint = this->mapTo(this->window(), localPoint);
	m_infopanel->move(windowPoint);

	//connect(m_infopanel, SIGNAL(windChanged()), this, SLOT(updateWindDirection()));
	//connect(m_infopanel, SIGNAL(sceneLoad()), this, SLOT(updateSceneName()));
}*/